<?php

namespace Drupal\custom_status_report\Element;

use Drupal\system\Element\StatusReportPage;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a custom status report page element.
 *
 * @RenderElement("custom_status_report_page")
 */
class CustomStatusReportPage extends StatusReportPage {

  /**
   * Constructs a CustomStatusReportPage object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function preRenderGeneralInfo($element) {
    $element = parent::preRenderGeneralInfo($element);

    // Get visibility settings.
    $config = \Drupal::config('custom_status_report.custom_status_report_settings');
    $visibility = \Drupal::config('custom_status_report.settings')->get('section_visibility');

    // Filter out hidden sections.
    foreach ($visibility as $section => $visible) {
      if (!$visible) {
        switch ($section) {
          case 'drupal':
            unset($element['#general_info']['#drupal']);
            break;
          case 'webserver':
            unset($element['#general_info']['#webserver']);
            break;
          case 'cron':
            unset($element['#general_info']['#cron']);
            break;
          case 'php':
            unset($element['#general_info']['#php']);
            unset($element['#general_info']['#php_memory_limit']);
            break;
          case 'database':
            unset($element['#general_info']['#database_system']);
            unset($element['#general_info']['#database_system_version']);
            break;
        }
      }
    }

    // Allow modules to add their information to the General Info section.
    foreach ($element['#requirements'] as $key => $requirement) {
      if (isset($requirement['add_to_general_info'])
        && $requirement['add_to_general_info'] === TRUE
        && array_key_exists($key, $visibility)
        && $visibility[$key] == 1) {
        $element['#general_info']['#other_modules'][$key] = $requirement;
      }
    }

    return $element;
  }

}
