<?php

namespace Drupal\custom_status_report\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Custom Status Report settings.
 */
class CustomStatusReportSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_status_report_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['custom_status_report.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form[] = [
      '#type' => 'markup',
      '#markup' => $this->t('<a class="button" href="/admin/reports/status">View the Status Report page</a>.'),
    ];


    $form['section_visibility'] = [
      '#type' => 'details',
      '#title' => $this->t('General System Information Card Visibility'),
      '#description' => $this->t('Control which cards are displayed in the General System Information section.'),
      '#open' => TRUE,
    ];
    $config = $this->config('custom_status_report.settings');
    $sections = [
      'drupal' => $this->t('Drupal Version'),
      'webserver' => $this->t('Web Server'),
      'cron' => $this->t('Last Cron Run'),
      'php' => $this->t('PHP Information'),
      'database' => $this->t('Database Information'),
    ];

    foreach ($sections as $key => $label) {
      $form['section_visibility']['drupal'][$key] = [
        '#type' => 'checkbox',
        '#title' => $label,
        '#default_value' => $config->get("section_visibility.$key") ?? TRUE,
      ];
    }

    $other_modules = $this->getOtherModules();
    $form['section_visibility'][] = [
      '#type' => 'markup',
      '#markup' => $this->t('<div class="csr-divider"><hr><span>Other Modules</span><hr></div>'),
    ];
    foreach ($other_modules as $key => $label) {
      $form['section_visibility']['other_modules'][$key] = [
        '#type' => 'checkbox',
        '#title' => $label,
        '#default_value' =>$config->get("section_visibility.$key") ?? TRUE,
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('custom_status_report.settings');
    $values = $form_state->getValues();

    foreach ($values as $section => $value) {
      if (!in_array($section, ['form_build_id', 'form_token', 'form_id', 'op', 'submit'])) {
        $config->set("section_visibility.$section", $value);
      }
    }

    $config->save();
//    \Drupal::service('cache_tags.invalidator')->invalidateTags(['config:core.extension']);
    parent::submitForm($form, $form_state);
  }

  /**
   * Get all modules who have implemented 'add_to_general_info' in hook_requirements().
   */
  private function getOtherModules() {

    $implementors = [];
    foreach (\Drupal::moduleHandler()->getModuleList() as $module => $info) {
      $has_hook = \Drupal::moduleHandler()->hasImplementations('requirements_alter', $module);
      if ($has_hook) {
        $implementors[$module] = \Drupal::service('extension.list.module')->getName($module);
      }
    }
    return $implementors;
  }

}
